#ifndef NETWORK_H
#define NETWORK_H

#define PORT 1505
#define HOST "projects.cs.illinois.edu"
#endif // NETWORK_H
